@@ -16,6 +16,11 @@ class Turkish(TurkishClass):
             history=self.history
         )
 
+    def plural(self, **kwargs):
+        self.set_plural()
+
+        return self.common_return(**kwargs)
+
     def accusative(self, **kwargs):
         """
             -i hali
@@ -180,46 +185,38 @@ class Turkish(TurkishClass):
 
         if not (person == '3' and plural):
             if not proper_noun:
+                self.ng_change()
+
                 self.soften()
 
                 self.exception_missing(proper_noun)
 
         if not plural:
             if person == '1':
-                self.ng_change()
-
                 if not self.last_letter_is_vowel():
                     self.concat(minor)
 
                 self.concat('m')
 
             elif person == '2':
-                self.ng_change()
-
                 if not self.last_letter_is_vowel():
                     self.concat(minor)
 
                 self.concat('n')
 
             elif person == '3':
-                self.ng_change()
-
                 if self.last_letter_is_vowel():
                     self.concat('s')
 
                 self.concat(minor)
         else:
             if person == '1':
-                self.ng_change()
-
                 if not self.last_letter_is_vowel():
                     self.concat(minor)
 
                 self.concat(f'm{minor}z')
 
             elif person == '2':
-                self.ng_change()
-
                 if not self.last_letter_is_vowel():
                     self.concat(minor)
 
@@ -228,8 +225,8 @@ class Turkish(TurkishClass):
                 if self.lower() == 'ism':
                     self.from_upper_or_lower('isim')
 
-                self.plural()
-                self.concat(minor)
+                self.make_plural()
+                self.concat(self.minor())
 
         return self.common_return(**kwargs)
 
@@ -339,7 +336,7 @@ class Turkish(TurkishClass):
                 elif kwargs.get('person', 3) == 2:
                     self.concat(' musunuz')
                 elif kwargs.get('person', 3) == 3:
-                    self.plural()
+                    self.make_plural()
                     self.concat(' m')
                     self.concat(self.letter_i())
         else:
@@ -354,7 +351,7 @@ class Turkish(TurkishClass):
                 elif kwargs.get('person', 3) == 2:
                     self.concat('sunuz')
                 elif kwargs.get('person', 3) == 3:
-                    self.plural()
+                    self.make_plural()
 
         return self.common_return(**kwargs)
     
@@ -392,7 +389,7 @@ class Turkish(TurkishClass):
                 self.concat(f's{self.minor()}n')
                 self.concat(f'{self.minor()}z')
             elif person == 3 and plural:
-                self.plural()
+                self.make_plural()
         else:
             if person == 1 and not plural:
                 self.concat(f' m{self.minor()}y')
@@ -410,7 +407,7 @@ class Turkish(TurkishClass):
                 self.concat(f's{self.minor()}n')
                 self.concat(f'{self.minor()}z')
             elif person == 3 and plural:
-                self.plural()
+                self.make_plural()
                 self.concat(f' m{self.minor()}')
 
         return self.common_return(**kwargs)
@@ -460,7 +457,7 @@ class Turkish(TurkishClass):
                 elif person == 2:
                     self.concat(f' m{minor}s{letter_i}n{letter_i}z')
                 elif person == 3:
-                    self.plural()
+                    self.make_plural()
                     minor = self.minor()
                     self.concat(f' m{minor}')
             elif negative:
@@ -487,7 +484,7 @@ class Turkish(TurkishClass):
                     elif person == 2:
                         self.concat(f' m{minor}s{letter_i}n{letter_i}z')
                     elif person == 3:
-                        self.plural()
+                        self.make_plural()
                         self.concat(f' m{minor}')
         else:  # not question
             harmony = self.harmony_for_present()
@@ -517,7 +514,7 @@ class Turkish(TurkishClass):
                     elif person == 2:
                         self.concat(f's{harmony}n{harmony}z')
                     elif person == 3:
-                        self.plural()
+                        self.make_plural()
             else:  # negative
                 ae = self.letter_a()
                 letter_i = self.letter_i()
@@ -547,7 +544,7 @@ class Turkish(TurkishClass):
                     if not from_able:
                         self.concat(f'm{ae}')
                     self.concat(f'z')
-                    self.plural()
+                    self.make_plural()
 
         return self.common_return(**kwargs)
 
@@ -591,7 +588,7 @@ class Turkish(TurkishClass):
                 letter_d = 't'
 
             self.concat(f'{letter_d}{self.minor()}')
-            self.plural()
+            self.make_plural()
 
         if kwargs.get('question', False):
             minor = self.minor()
@@ -612,7 +609,7 @@ class Turkish(TurkishClass):
         ).to_string()
 
         if person == 3 and plural:
-            self.plural()
+            self.make_plural()
             plural = False
 
         if question:
@@ -685,7 +682,7 @@ class Turkish(TurkishClass):
             elif person == 2:
                 self.concat(f's{minor}n{minor}z')
             elif person == 3 and plural:
-                self.plural()
+                self.make_plural()
         else:
             if person == 1 and not plural:
                 self.concat(f' m{minor}y{minor}m')
@@ -698,7 +695,7 @@ class Turkish(TurkishClass):
             elif person == 2:
                 self.concat(f' m{minor}s{minor}n{minor}z')
             elif person == 3:
-                self.plural()
+                self.make_plural()
                 self.concat(f' m{minor}')
 
         return self.common_return(**kwargs)
@@ -808,7 +805,7 @@ class Turkish(TurkishClass):
             ).to_string()
         else:
             if kwargs.get('person', 3) == 3 and kwargs.get('plural', False):
-                self.plural()
+                self.make_plural()
                 minor = self.minor()
 
                 self.concat(f' m{minor}ym{minor}ş')
@@ -851,7 +848,7 @@ class Turkish(TurkishClass):
         self.concat(f's{letter_a}')
 
         if person == 3 and plural:
-            self.plural()
+            self.make_plural()
 
         if kwargs.get('question'):
             self.concat(f' m{letter_i}yd{letter_i}')
@@ -880,12 +877,14 @@ class Turkish(TurkishClass):
         self.concat(f's{letter_a}')
 
         if person == 3 and plural:
-            self.plural()
+            self.make_plural()
 
         if kwargs.get('question'):
             self.concat(f' m{letter_i}')
 
-        self.concat(f'ym{letter_i}ş')
+        self.if_ends_with_vowel('y')
+
+        self.concat(f'm{letter_i}ş')
 
         if person == 1 and not plural:
             self.concat(f'{letter_i}m')
@@ -970,7 +969,7 @@ class Turkish(TurkishClass):
         plural = kwargs.get('plural')
 
         if person == 3 and plural:
-            self.plural()
+            self.make_plural()
 
         letter_i = self.letter_i()
         if self.last_letter_is_hard():
@@ -1012,7 +1011,7 @@ class Turkish(TurkishClass):
         plural = kwargs.get('plural')
 
         if person == 3 and plural:
-            self.plural()
+            self.make_plural()
 
         letter_i = self.letter_i()
 
@@ -1050,7 +1049,7 @@ class Turkish(TurkishClass):
         plural = kwargs.get('plural')
 
         if person == 3 and plural:
-            self.plural()
+            self.make_plural()
         self.concat(f's{letter_a}')
 
         if person == 1 and not plural:
@@ -1076,36 +1075,28 @@ class Turkish(TurkishClass):
             Approach - Yaklaşma: (yaz) düzeyaz
         """
         self.verbs_losing_vowels()
-
-        minor = self.minor()
-
         self.if_ends_with_vowel('y')
-
         self.soften()
-        ae = self.letter_a()
-
         self.harden_verb()
 
         if not kwargs.get('negative', False):
             if kwargs.get('auxiliary') in ['ver', 'koy']:
-                self.concat(minor)
+                self.concat(self.minor())
             else:
-                self.concat(ae)
+                self.concat(self.letter_a())
 
             self.concat(kwargs.get('auxiliary'))
         if kwargs.get('negative', False):
             if kwargs.get('auxiliary') == 'bil':
-                self.concat(f'{ae}m{ae}')
+                self.concat(f'{self.letter_a()}m{self.letter_a()}')
             else:
                 if kwargs.get('auxiliary') in ['ver', 'koy']:
-                    self.concat(minor)
+                    self.concat(self.minor())
                 else:
-                    self.concat(ae)
+                    self.concat(self.letter_a())
 
                 self.concat(kwargs.get('auxiliary'))
 
-                self.concat(ae)
-
         return self.common_return(**kwargs)
 
     def necessitative_mood(self, **kwargs):
@@ -1130,7 +1121,7 @@ class Turkish(TurkishClass):
         self.necessitative_mood()
 
         if kwargs.get('person', 3) == 3 and kwargs.get('plural'):
-            self.plural()
+            self.make_plural()
 
         if kwargs.get('question', False):
             self.concat(f' m{letter_i}')
@@ -1160,7 +1151,7 @@ class Turkish(TurkishClass):
         self.necessitative_mood()
 
         if kwargs.get('person', 3) == 3 and kwargs.get('plural'):
-            self.plural()
+            self.make_plural()
 
         if kwargs.get('question', False):
             self.concat(f' m{letter_i}')
@@ -1195,7 +1186,7 @@ class Turkish(TurkishClass):
         plural = kwargs.get('plural')
 
         if person == 3 and plural:
-            self.plural()
+            self.make_plural()
 
         if kwargs.get('question', False):
             self.concat(f' m{letter_i}')
@@ -1264,7 +1255,7 @@ class Turkish(TurkishClass):
 
         elif person == 3 and plural:
             self.concat(f's{minor}n')
-            self.plural()
+            self.make_plural()
 
             if question:
                 self.concat(f' m{self.minor()}')
@@ -1296,7 +1287,7 @@ class Turkish(TurkishClass):
             elif kwargs.get('person', 3) == 2:
                 self.concat(f'n{letter_i}z')
             elif kwargs.get('person', 3) == 3:
-                self.plural()
+                self.make_plural()
 
         if kwargs.get('question', False):
             self.concat(f' m{letter_i}')
@@ -1339,7 +1330,7 @@ class Turkish(TurkishClass):
             elif kwargs.get('person', 3) == 2:
                 self.concat(f's{letter_i}n{letter_i}z')
             elif kwargs.get('person', 3) == 3:
-                self.plural()
+                self.make_plural()
 
         if kwargs.get('question', False):
             self.concat(f' m{letter_i}')
@@ -1368,7 +1359,7 @@ class Turkish(TurkishClass):
         ).to_string()
 
         if person == 3 and plural:
-            self.plural()
+            self.make_plural()
 
         if question:
             self.concat(f' m{self.minor()}')
@@ -1411,7 +1402,7 @@ class Turkish(TurkishClass):
             ).to_string()
 
             if kwargs.get('person', 3) == 3 and kwargs.get('plural', False):
-                self.plural()
+                self.make_plural()
 
             letter_i = self.letter_i()
 
@@ -1489,7 +1480,7 @@ class Turkish(TurkishClass):
         ).to_string()
 
         if person == 3 and plural:
-            self.plural()
+            self.make_plural()
 
         if question:
             self.concat(f' m{self.minor()}')
